# arpes.fits package

## Submodules

  - [arpes.fits.fit\_models module](arpes.fits.fit_models)
  - [arpes.fits.lmfit\_html\_repr module](arpes.fits.lmfit_html_repr)
  - [arpes.fits.lmfit\_plot module](arpes.fits.lmfit_plot)
  - [arpes.fits.utilities module](arpes.fits.utilities)

## Module contents
